@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2024 gt authors
+#  Copyright (c) 2018-2025 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -256,6 +256,7 @@ dt_options_tbl <-
     "ihtml_page_size_default",           FALSE,  "interactive",      "values",  10,
     "ihtml_page_size_values",            FALSE,  "interactive",      "values",  default_page_size_vec,
     "ihtml_pagination_type",             FALSE,  "interactive",      "value",   "numbers",
+    "ihtml_selection_mode",              FALSE,  "interactive",      "value",   NA_character_,
     "page_orientation",                  FALSE,  "page",             "value",   "portrait",
     "page_numbering",                    FALSE,  "page",             "logical", FALSE,
     "page_header_use_tbl_headings",      FALSE,  "page",             "logical", FALSE,
@@ -271,5 +272,5 @@ dt_options_tbl <-
     "quarto_disable_processing",         FALSE,  "quarto",           "logical", FALSE,
     "quarto_use_bootstrap",              FALSE,  "quarto",           "logical", FALSE,
     "latex_use_longtable",               FALSE,  "latex",            "logical", FALSE,
-    "latex_tbl_pos",                     FALSE,  "latex",            "value",   "!t",
+    "latex_tbl_pos",                     FALSE,  "latex",            "value",   "t",
   )[-1, ]
