@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2024 gt authors
+#  Copyright (c) 2018-2025 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -46,10 +46,7 @@ footnote_mark_to_latex <- function(
   }
 
   spec <- get_footnote_spec_by_location(data = data, location = location)
-
-  if (is.null(spec)) {
-    spec <- "^i"
-  }
+  spec <- spec %||% "^i"
 
   if (grepl(".", spec, fixed = TRUE)) mark <- sprintf_unless_na("%s.", mark)
   if (grepl("b", spec, fixed = TRUE)) mark <- sprintf_unless_na("\\textbf{%s}", mark)
@@ -156,10 +153,10 @@ create_table_start_l <- function(data, colwidth_df) {
   if ("group_label" %in% stub_layout) {
     types <- c(types, "row_group")
   }
-  
+
   colwidth_df_visible <- colwidth_df[colwidth_df$type %in% types, ]
-  
-  # Ensure that the `colwidth_df_visible` df rows are sorted such that the 
+
+  # Ensure that the `colwidth_df_visible` df rows are sorted such that the
   # `"row_group"` row is first (only if it's located in the stub), then `"stub"`,
   # and then everything else
   if ("stub" %in% colwidth_df_visible[["type"]]) {
@@ -167,7 +164,7 @@ create_table_start_l <- function(data, colwidth_df) {
     othr_idx <- base::setdiff(seq_len(nrow(colwidth_df_visible)), stub_idx)
     colwidth_df_visible <- vctrs::vec_slice(colwidth_df_visible, c(stub_idx, othr_idx))
   }
-  
+
   if ("row_group" %in% colwidth_df_visible[["type"]]) {
     row_group_idx <- which(colwidth_df_visible$type == "row_group")
     othr_idx <- base::setdiff(seq_len(nrow(colwidth_df_visible)), row_group_idx)
@@ -200,7 +197,7 @@ create_table_start_l <- function(data, colwidth_df) {
     col_defs <- NULL
 
     for (i in seq_len(nrow(colwidth_df_visible))) {
-      
+
       if (colwidth_df_visible$unspec[i] == 1L) {
         col_defs_i <- substr(colwidth_df_visible$column_align[i], 1, 1)
       } else {
@@ -228,7 +225,7 @@ create_table_start_l <- function(data, colwidth_df) {
     }
 
   } else {
-    
+
     col_defs <- substr(colwidth_df_visible$column_align, 1, 1)
   }
 
@@ -241,7 +238,7 @@ create_table_start_l <- function(data, colwidth_df) {
 
   # If a table width is specified, add an extra column
   # space to fill in enough space to match the width
-  extra_sep <- ''
+  extra_sep <- ""
   if (dt_options_get_value(data = data, option = "table_width") != "auto")
     extra_sep <- "@{\\extracolsep{\\fill}}"
 
@@ -250,8 +247,8 @@ create_table_start_l <- function(data, colwidth_df) {
   if(!dt_options_get_value(data = data, option = "latex_use_longtable")) {
 
     # we need to use the extracolsep here for tabular* regardless of width
-    extra_sep <- '@{\\extracolsep{\\fill}}'
-    table_width <- dt_options_get_value(data = data, 'table_width')
+    extra_sep <- "@{\\extracolsep{\\fill}}"
+    table_width <- dt_options_get_value(data = data, "table_width")
 
     if (endsWith(table_width, "%")) {
 
@@ -547,9 +544,9 @@ create_columns_component_l <- function(data, colwidth_df) {
       span_widths <- calculate_multicolumn_width_text_l(begins = firsts, ends = lasts, colwidth_df = colwidth_df)
       tex_widths <-
         ifelse(
-          span_widths == "",
-          "c",
-          paste0(">{\\centering\\arraybackslash}m{", span_widths, "}")
+          nzchar(span_widths),
+          paste0(">{\\centering\\arraybackslash}m{", span_widths, "}"),
+          "c"
         )
 
       multicol <-
@@ -1387,11 +1384,11 @@ split_row_content <- function(x) {
 
 derive_table_width_statement_l <- function(data) {
 
-  table_width <- dt_options_get_value(data = data, 'table_width')
+  table_width <- dt_options_get_value(data = data, "table_width")
 
   # Bookends are not required if a table width is not specified
   # of if using floating table
-  if (table_width == 'auto' ||
+  if (table_width == "auto" ||
       !dt_options_get_value(data = data, option = "latex_use_longtable")) {
 
     statement <- ''
@@ -1518,11 +1515,11 @@ apply_cell_styles_l <- function(content, style_obj) {
   if (is.null(style_obj[["cell_text"]][["style"]])) return(NULL)
 
   switch(
-    style_obj[['cell_text']][['style']],
-    italic = '\\itshape ',
-    oblique = '\\slshape ',
-    normal = '\\upshape ',
-    ''
+    style_obj[["cell_text"]][["style"]],
+    italic = "\\itshape ",
+    oblique = "\\slshape ",
+    normal = "\\upshape ",
+    ""
   )
 
 }
@@ -1542,17 +1539,17 @@ apply_cell_styles_l <- function(content, style_obj) {
 
 .apply_style_weight_l <- function(style_obj) {
 
-  if (is.null(style_obj[['cell_text']][['weight']])) return('')
+  if (is.null(style_obj[["cell_text"]][["weight"]])) return("")
 
   # TODO:  Figure out how to implement weights expressed as numbers.
-  if (is.numeric(style_obj[['cell_text']][['weight']])) return('')
+  if (is.numeric(style_obj[["cell_text"]][["weight"]])) return("")
 
   switch(
-    style_obj[['cell_text']][['weight']],
-    normal = '\\mdseries ',
-    bold = '\\bfseries ',
-    bolder = '\\bfseries ',  # Not implemented
-    lighter = '\\mdseries ', # lfseries is not fully supported in Latex - caused errors with some fonts
+    style_obj[["cell_text"]][["weight"]],
+    normal = "\\mdseries ",
+    bold = "\\bfseries ",
+    bolder = "\\bfseries ",  # Not implemented
+    lighter = "\\mdseries ", # lfseries is not fully supported in Latex - caused errors with some fonts
     ''
   )
 
@@ -1574,9 +1571,9 @@ apply_cell_styles_l <- function(content, style_obj) {
 
 .apply_style_fontsize_l <- function(style_obj) {
 
-  if (is.null(style_obj[['cell_text']][['size']])) return('')
+  if (is.null(style_obj[["cell_text"]][["size"]])) return("")
 
-  if (is.numeric(style_obj[['cell_text']][['size']])) {
+  if (is.numeric(style_obj[["cell_text"]][["size"]])) {
     # According to the documentation for the cell_text function,
     # numeric values are assumed to be in pixels.  Latex requires
     # points
@@ -1584,26 +1581,26 @@ apply_cell_styles_l <- function(content, style_obj) {
     return(
       paste0(
         "\\fontsize{",
-        style_obj[['cell_text']][['size']] * 0.75,
+        style_obj[["cell_text"]][["size"]] * 0.75,
         "}{",
-        style_obj[['cell_text']][['size']] * 0.75 * 1.25,
+        style_obj[["cell_text"]][["size"]] * 0.75 * 1.25,
         "}\\selectfont "
       )
     )
 
   }
 
-  convert_font_size_l(style_obj[['cell_text']][['size']])
+  convert_font_size_l(style_obj[["cell_text"]][["size"]])
 
 }
 
 .apply_style_color_l <- function(x, style_obj) {
 
-  if (is.null(style_obj[['cell_text']][['color']])) return(x)
+  if (is.null(style_obj[["cell_text"]][["color"]])) return(x)
 
   paste0(
     "\\textcolor[HTML]{",
-    gsub("#", "", style_obj[['cell_text']][['color']], fixed = TRUE),
+    gsub("#", "", style_obj[["cell_text"]][["color"]], fixed = TRUE),
     "}{", x, "}"
   )
 }
@@ -1710,7 +1707,7 @@ create_colwidth_df_l <- function(data) {
     pt = rep.int(0L, n),
     column_align = boxhead$column_align
   )
-  
+
   width_df$column_align[width_df$type %in% c("stub", "row_group")] <- "left"
 
   for (i in 1:n) {
