@@ -1,24 +1,23 @@
-test_that("The `gt_preview()` function works correctly", {
+test_that("gt_preview() works correctly", {
 
   # Ensure that gt objects still work with `gt_preview()`
-  expect_equal(
-    gt_preview(mtcars) %>% class(),
-    gt_preview(mtcars %>% gt()) %>% class()
+  expect_s3_class(
+    gt_preview(mtcars),
+    gt_preview(mtcars %>% gt()) %>% class(),
+    exact = TRUE
   )
 
   # Create a basic preview of the `mtcars` dataset
   gt_tbl <- gt_preview(mtcars)
 
-  built_tbl <- gt_tbl %>% build_data(context = "html")
-  output_tbl <- dt_body_get(data = built_tbl)
+  built_tbl <-  build_data(gt_tbl, context = "html")
+  output_tbl <- dt_body_get(built_tbl)
 
   # Expect that the output table has had rows removed
   nrow(mtcars) %>% expect_gt(nrow(output_tbl))
 
   # Expect certain row names in `data_df`
-  output_tbl %>%
-    dplyr::pull(rowname) %>%
-    expect_equal(c("1", "2", "3", "4", "5", "6..31", "32"))
+  expect_equal(output_tbl$rowname, c("1", "2", "3", "4", "5", "6..31", "32"))
 
   # Expect mostly empty strings in the ellipsis row
   # (row `6` in this case)
@@ -35,12 +34,11 @@ test_that("The `gt_preview()` function works correctly", {
 
   # Expect a preview of the `mtcars` dataset with different `top_n`
   # and `bottom_n` values will result in a different row names
-  output_tbl %>%
-    dplyr::pull(rowname) %>%
-    expect_equal(
-      c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
-        "11..27", "28", "29", "30", "31", "32")
-    )
+  expect_equal(
+    output_tbl$rowname,
+    c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
+      "11..27", "28", "29", "30", "31", "32")
+  )
 
   # Expect empty strings in the ellipsis row (row `11` in this case)
   output_tbl[11, ] %>%
@@ -51,18 +49,15 @@ test_that("The `gt_preview()` function works correctly", {
   # Create a preview table with a 5-row version of `mtcars`
   gt_tbl <- gt_preview(mtcars[1:5, ])
 
-  built_tbl <- gt_tbl %>% build_data(context = "html")
-  output_tbl <- dt_body_get(data = built_tbl)
+  built_tbl <- build_data(gt_tbl, context = "html")
+  output_tbl <- dt_body_get(built_tbl)
 
   # Expect a preview of this shortened `mtcars` dataset won't
   # have an ellipsis row
-  output_tbl %>%
-    dplyr::pull(rowname) %>%
-    expect_equal(c("1", "2", "3", "4", "5"))
+  expect_equal(output_tbl$rowname, c("1", "2", "3", "4", "5"))
 
   # Expect no empty strings along the `mpg` column
-  output_tbl$mpg %>%
-    expect_equal(c("21.0", "21.0", "22.8", "21.4", "18.7"))
+  expect_equal(output_tbl$mpg, c("21.0", "21.0", "22.8", "21.4", "18.7"))
 
   # Create a table that has `groupname` and `rowname` columns
   tbl <-
@@ -76,16 +71,15 @@ test_that("The `gt_preview()` function works correctly", {
   # Create a preview table with the `tbl` table
   gt_tbl <- gt_preview(tbl)
 
-  built_tbl <- gt_tbl %>% build_data(context = "html")
-  output_tbl <- dt_body_get(data = built_tbl)
+  built_tbl <- build_data(gt_tbl, context = "html")
+  output_tbl <- dt_body_get(built_tbl)
 
   # Expect that columns named `rowname` or `groupname` will
   # gain a leading `.` to demote them from acting as magic columns
-  output_tbl %>%
-    colnames() %>%
-    expect_equal(
-      c("rowname", ".groupname", ".rowname", "value", "value_2")
-    )
+  expect_named(
+    output_tbl,
+    c("rowname", ".groupname", ".rowname", "value", "value_2")
+  )
 
   # Create a preview table that doesn't include row numbers
   gt_tbl <- gt_preview(mtcars, incl_rownums = FALSE)
@@ -95,9 +89,10 @@ test_that("The `gt_preview()` function works correctly", {
 
   # Expect the column names to be equal to that of the
   # input data table
-  output_tbl %>%
-    colnames() %>%
-    expect_equal(colnames(mtcars))
+  expect_equal(
+    colnames(output_tbl),
+    colnames(mtcars)
+  )
 
   # Expect no errors when using all gt datasets (plus a few more
   # from the datasets package) with the `gt_preview()` function
