@@ -1,4 +1,4 @@
-test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
+test_that("fmt_percent() works correctly in the LaTeX context", {
 
   # Create an input data frame four columns: two
   # character-based and two that are numeric
@@ -24,8 +24,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623.00\\%$", "$276,339.00\\%$", "$93,729.00\\%$",
-      "$64,300.00\\%$", "$21,223.20\\%$", "$0.00\\%$", "$-2,324.00\\%$"
+      "183,623.00\\%", "276,339.00\\%", "93,729.00\\%",
+      "64,300.00\\%", "21,223.20\\%", "0.00\\%", "-2,324.00\\%"
     )
   )
 
@@ -36,9 +36,9 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 5) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623.00000\\%$", "$276,339.00000\\%$", "$93,729.00000\\%$",
-      "$64,300.00000\\%$", "$21,223.20000\\%$", "$0.00000\\%$",
-      "$-2,324.00000\\%$"
+      "183,623.00000\\%", "276,339.00000\\%", "93,729.00000\\%",
+      "64,300.00000\\%", "21,223.20000\\%", "0.00000\\%",
+      "-2,324.00000\\%"
     )
   )
 
@@ -53,8 +53,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623\\%$", "$276,339\\%$", "$93,729\\%$", "$64,300\\%$",
-      "$21,223.2\\%$", "$0\\%$", "$-2,324\\%$"
+      "183,623\\%", "276,339\\%", "93,729\\%", "64,300\\%",
+      "21,223.2\\%", "0\\%", "-2,324\\%"
     )
   )
 
@@ -66,8 +66,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, use_seps = FALSE) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183623.00\\%$", "$276339.00\\%$", "$93729.00\\%$", "$64300.00\\%$",
-      "$21223.20\\%$", "$0.00\\%$", "$-2324.00\\%$"
+      "183623.00\\%", "276339.00\\%", "93729.00\\%", "64300.00\\%",
+      "21223.20\\%", "0.00\\%", "-2324.00\\%"
     )
   )
 
@@ -79,8 +79,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, sep_mark = " ") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183 623.00\\%$", "$276 339.00\\%$", "$93 729.00\\%$", "$64 300.00\\%$",
-      "$21 223.20\\%$", "$0.00\\%$", "$-2 324.00\\%$"
+      "183 623.00\\%", "276 339.00\\%", "93 729.00\\%", "64 300.00\\%",
+      "21 223.20\\%", "0.00\\%", "-2 324.00\\%"
     )
   )
 
@@ -95,8 +95,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183.623,00\\%$", "$276.339,00\\%$", "$93.729,00\\%$", "$64.300,00\\%$",
-      "$21.223,20\\%$", "$0,00\\%$", "$-2.324,00\\%$"
+      "183.623,00\\%", "276.339,00\\%", "93.729,00\\%", "64.300,00\\%",
+      "21.223,20\\%", "0,00\\%", "-2.324,00\\%"
     )
   )
 
@@ -108,9 +108,9 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, pattern = "a {x}:n") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "a $183,623.00\\%$:n", "a $276,339.00\\%$:n", "a $93,729.00\\%$:n",
-      "a $64,300.00\\%$:n", "a $21,223.20\\%$:n", "a $0.00\\%$:n",
-      "a $-2,324.00\\%$:n"
+      "a 183,623.00\\%:n", "a 276,339.00\\%:n", "a 93,729.00\\%:n",
+      "a 64,300.00\\%:n", "a 21,223.20\\%:n", "a 0.00\\%:n",
+      "a -2,324.00\\%:n"
     )
   )
 
@@ -125,8 +125,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623 \\%$", "$276,339 \\%$", "$93,729 \\%$", "$64,300 \\%$",
-      "$21,223 \\%$", "$0 \\%$", "$-2,324 \\%$"
+      "183,623 \\%", "276,339 \\%", "93,729 \\%", "64,300 \\%",
+      "21,223 \\%", "0 \\%", "-2,324 \\%"
     )
   )
 
@@ -141,8 +141,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$\\% 183,623$", "$\\% 276,339$", "$\\% 93,729$", "$\\% 64,300$",
-      "$\\% 21,223$", "$\\% 0$", "$-\\% 2,324$"
+      "\\% 183,623", "\\% 276,339", "\\% 93,729", "\\% 64,300",
+      "\\% 21,223", "\\% 0", "-\\% 2,324"
     )
   )
 
@@ -152,8 +152,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, accounting = TRUE) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623.00\\%$", "$276,339.00\\%$", "$93,729.00\\%$", "$64,300.00\\%$",
-      "$21,223.20\\%$", "$0.00\\%$", "$(2,324.00\\%)$"
+      "183,623.00\\%", "276,339.00\\%", "93,729.00\\%", "64,300.00\\%",
+      "21,223.20\\%", "0.00\\%", "(2,324.00\\%)"
     )
   )
 
@@ -163,8 +163,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 3, accounting = TRUE) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623.000\\%$", "$276,339.000\\%$", "$93,729.000\\%$",
-      "$64,300.000\\%$", "$21,223.200\\%$", "$0.000\\%$", "$(2,324.000\\%)$"
+      "183,623.000\\%", "276,339.000\\%", "93,729.000\\%",
+      "64,300.000\\%", "21,223.200\\%", "0.000\\%", "(2,324.000\\%)"
     )
   )
 
@@ -177,8 +177,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
          accounting = TRUE, pattern = "a{x}b") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "a$183,623.000\\%$b", "a$276,339.000\\%$b", "a$93,729.000\\%$b",
-      "a$64,300.000\\%$b", "a$21,223.200\\%$b", "a$0.000\\%$b", "a$(2,324.000\\%)$b"
+      "a183,623.000\\%b", "a276,339.000\\%b", "a93,729.000\\%b",
+      "a64,300.000\\%b", "a21,223.200\\%b", "a0.000\\%b", "a(2,324.000\\%)b"
     )
   )
 
@@ -191,8 +191,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
          accounting = TRUE, drop_trailing_zeros = TRUE) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623\\%$", "$276,339\\%$", "$93,729\\%$", "$64,300\\%$",
-      "$21,223.2\\%$", "$0\\%$", "$(2,324\\%)$"
+      "183,623\\%", "276,339\\%", "93,729\\%", "64,300\\%",
+      "21,223.2\\%", "0\\%", "(2,324\\%)"
     )
   )
 
@@ -205,8 +205,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$+1,836.23\\%$", "$+2,763.39\\%$", "$+937.29\\%$", "$+643\\%$",
-      "$+212.23\\%$", "$0\\%$", "$-23.24\\%$"
+      "+1,836.23\\%", "+2,763.39\\%", "+937.29\\%", "+643\\%",
+      "+212.23\\%", "0\\%", "-23.24\\%"
     )
   )
 
@@ -237,8 +237,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        ) %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "*$+183,623\\%$*", "*$+276,339\\%$*", "*$+93,729\\%$*",
-      "*$+64,300\\%$*", "*$+21,223.2\\%$*", "*$0\\%$*", "*$-2,324\\%$*"
+      "*+183,623\\%*", "*+276,339\\%*", "*+93,729\\%*",
+      "*+64,300\\%*", "*+21,223.2\\%*", "*0\\%*", "*-2,324\\%*"
     )
   )
 
@@ -250,8 +250,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, locale = "en_US") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183,623.00\\%$", "$276,339.00\\%$", "$93,729.00\\%$",
-      "$64,300.00\\%$", "$21,223.20\\%$", "$0.00\\%$", "$-2,324.00\\%$"
+      "183,623.00\\%", "276,339.00\\%", "93,729.00\\%",
+      "64,300.00\\%", "21,223.20\\%", "0.00\\%", "-2,324.00\\%"
     )
   )
 
@@ -263,8 +263,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, locale = "da_DK") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183.623,00\\%$", "$276.339,00\\%$", "$93.729,00\\%$",
-      "$64.300,00\\%$", "$21.223,20\\%$", "$0,00\\%$", "$-2.324,00\\%$"
+      "183.623,00\\%", "276.339,00\\%", "93.729,00\\%",
+      "64.300,00\\%", "21.223,20\\%", "0,00\\%", "-2.324,00\\%"
     )
   )
 
@@ -276,8 +276,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, locale = "de_AT") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183 623,00\\%$", "$276 339,00\\%$", "$93 729,00\\%$",
-      "$64 300,00\\%$", "$21 223,20\\%$", "$0,00\\%$", "$-2 324,00\\%$"
+      "183 623,00\\%", "276 339,00\\%", "93 729,00\\%",
+      "64 300,00\\%", "21 223,20\\%", "0,00\\%", "-2 324,00\\%"
     )
   )
 
@@ -289,8 +289,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, locale = "et_EE") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183 623,00\\%$", "$276 339,00\\%$", "$93 729,00\\%$",
-      "$64 300,00\\%$", "$21 223,20\\%$", "$0,00\\%$", "$-2 324,00\\%$"
+      "183 623,00\\%", "276 339,00\\%", "93 729,00\\%",
+      "64 300,00\\%", "21 223,20\\%", "0,00\\%", "-2 324,00\\%"
     )
   )
 
@@ -302,8 +302,8 @@ test_that("The `fmt_percent()` function works correctly in the LaTeX context", {
        fmt_percent(columns = num_1, decimals = 2, locale = "gl_ES") %>%
        render_formats_test("latex"))[["num_1"]],
     c(
-      "$183.623,00\\%$", "$276.339,00\\%$", "$93.729,00\\%$",
-      "$64.300,00\\%$", "$21.223,20\\%$", "$0,00\\%$", "$-2.324,00\\%$"
+      "183.623,00\\%", "276.339,00\\%", "93.729,00\\%",
+      "64.300,00\\%", "21.223,20\\%", "0,00\\%", "-2.324,00\\%"
     )
   )
 })
